@@ -16,8 +16,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Authors: Darin Adler <darin@eazel.com>
 */
@@ -396,17 +395,12 @@ show_message_dialog (const char *primary_text,
 		     const char *secondary_text,
 		     GtkMessageType type,
 		     GtkButtonsType buttons_type,
-		     const char *details_text,
 		     GtkWindow *parent)
 {
 	GtkDialog *dialog;
 
 	dialog = create_message_dialog (primary_text, secondary_text, type, 
 					buttons_type, parent);
-	if (details_text != NULL) {
-		eel_gtk_message_dialog_set_details_label (GTK_MESSAGE_DIALOG (dialog),
-							  details_text);
-	}
 	gtk_widget_show (GTK_WIDGET (dialog));
 
 	g_signal_connect (dialog, "response",
@@ -424,23 +418,12 @@ show_ok_dialog (const char *primary_text,
 	GtkDialog *dialog;
 
 	dialog = show_message_dialog (primary_text, secondary_text, type,
-				      GTK_BUTTONS_OK, NULL, parent);
+				      GTK_BUTTONS_OK, parent);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	
 	return dialog;
 }
 
-GtkDialog *
-eel_create_info_dialog (const char *primary_text,
-			const char *secondary_text,
-			GtkWindow *parent)
-{
-	return create_message_dialog (primary_text, secondary_text,
-				      GTK_MESSAGE_INFO,
-				      GTK_BUTTONS_OK,
-				      parent);
-}
-
 GtkDialog *
 eel_show_info_dialog (const char *primary_text,
 		      const char *secondary_text,
@@ -451,31 +434,6 @@ eel_show_info_dialog (const char *primary_text,
 			    GTK_MESSAGE_INFO, parent);
 }
 
-GtkDialog *
-eel_show_info_dialog_with_details (const char *primary_text,
-				   const char *secondary_text,
-				   const char *detailed_info,
-				   GtkWindow *parent)
-{
-	GtkDialog *dialog;
-
-	if (detailed_info == NULL
-	    || strcmp (primary_text, detailed_info) == 0) {
-		return eel_show_info_dialog (primary_text, secondary_text, parent);
-	}
-
-	dialog = show_message_dialog (primary_text,
-				      secondary_text,
-				      GTK_MESSAGE_INFO, 
-				      GTK_BUTTONS_OK,
-				      detailed_info,
-				      parent);
-
-	return dialog;
-
-}
-
-
 GtkDialog *
 eel_show_warning_dialog (const char *primary_text,
 			 const char *secondary_text,
@@ -497,30 +455,6 @@ eel_show_error_dialog (const char *primary_text,
 			       GTK_MESSAGE_ERROR, parent);
 }
 
-GtkDialog *
-eel_show_error_dialog_with_details (const char *primary_text,
-				    const char *secondary_text,
-				    const char *detailed_error_message,
-				    GtkWindow *parent)
-{
-	GtkDialog *dialog;
-
-	g_return_val_if_fail (primary_text != NULL, NULL);
-	g_return_val_if_fail (parent == NULL || GTK_IS_WINDOW (parent), NULL);
-
-	if (detailed_error_message == NULL
-	    || strcmp (primary_text, detailed_error_message) == 0) {
-		return eel_show_error_dialog (primary_text, secondary_text, parent);
-	}
-	
-	dialog = show_message_dialog (primary_text, 
-				      secondary_text,
-				      GTK_MESSAGE_ERROR,
-				      GTK_BUTTONS_OK, detailed_error_message,
-				      parent);
-	return dialog;
-}
-
 /**
  * eel_show_yes_no_dialog:
  * 
