@@ -17,8 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * see <http://www.gnu.org/licenses/>.
  *
  * Authors: John Sullivan <sullivan@eazel.com>
  *          Cosimo Cecchi <cosimoc@redhat.com>
@@ -347,7 +346,14 @@ nautilus_bookmark_connect_file (NautilusBookmark *bookmark)
 		DEBUG ("%s: creating file", nautilus_bookmark_get_name (bookmark));
 
 		bookmark->details->file = nautilus_file_get (bookmark->details->location);
-		g_assert (!nautilus_file_is_gone (bookmark->details->file));
+                /* Similar to what we do when a file has been trashed or deleted
+                 * withouth noticing in bookmark_changed, just try to fall graciously.
+                 */
+                if (nautilus_file_is_gone (bookmark->details->file))
+                  {
+                        nautilus_bookmark_disconnect_file (bookmark);
+                        return;
+                  }
 
 		g_signal_connect_object (bookmark->details->file, "changed",
 					 G_CALLBACK (bookmark_file_changed_callback), bookmark, 0);
@@ -388,6 +394,7 @@ static gboolean
 exists_non_native_idle_cb (gpointer user_data)
 {
 	NautilusBookmark *bookmark = user_data;
+	bookmark->details->exists_id = 0;
 	nautilus_bookmark_set_exists (bookmark, FALSE);
 
 	return FALSE;
@@ -634,28 +641,6 @@ nautilus_bookmark_get_has_custom_name (NautilusBookmark *bookmark)
 	return (bookmark->details->has_custom_name);
 }
 
-/**
- * nautilus_bookmark_set_custom_name:
- *
- * Change the user-displayed name of a bookmark.
- * @new_name: The new user-displayed name for this bookmark, mustn't be NULL.
- *
- **/
-void
-nautilus_bookmark_set_custom_name (NautilusBookmark *bookmark,
-				   const char *new_name)
-{
-	g_return_if_fail (new_name != NULL);
-	g_return_if_fail (NAUTILUS_IS_BOOKMARK (bookmark));
-
-	g_object_set (bookmark,
-		      "custom-name", TRUE,
-		      "name", new_name,
-		      NULL);
-
-	g_signal_emit (bookmark, signals[CONTENTS_CHANGED], 0);
-}
-
 /**
  * nautilus_bookmark_compare_with:
  *
@@ -799,9 +784,3 @@ nautilus_bookmark_get_scroll_pos (NautilusBookmark      *bookmark)
 {
 	return g_strdup (bookmark->details->scroll_file);
 }
-
-gboolean
-nautilus_bookmark_get_exists (NautilusBookmark *bookmark)
-{
-	return bookmark->details->exists;
-}
