@@ -578,41 +578,3 @@ nautilus_get_icon_size_for_stock_size (GtkIconSize size)
   } 
   return NAUTILUS_CANVAS_ICON_SIZE_SMALL;
 }
-
-
-guint
-nautilus_icon_get_emblem_size_for_icon_size (guint size)
-{
-	if (size >= 96)
-		return 48;
-	if (size >= 64)
-		return 32;
-	if (size >= 48)
-		return 24;
-	if (size >= 24)
-		return 16;
-	if (size >= 16)
-		return 12;
-	
-	return 0; /* no emblems for smaller sizes */
-}
-
-gboolean
-nautilus_icon_theme_can_render (GThemedIcon *icon)
-{
-	GtkIconTheme *icon_theme;
-	const gchar * const *names;
-	gint idx;
-
-	names = g_themed_icon_get_names (icon);
-
-	icon_theme = gtk_icon_theme_get_default ();
-
-	for (idx = 0; names[idx] != NULL; idx++) {
-		if (gtk_icon_theme_has_icon (icon_theme, names[idx])) {
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
