@@ -14,20 +14,21 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * see <http://www.gnu.org/licenses/>.
  *
  * Author: Jamie McCracken <jamiemcc@gnome.org>
  *
  */
 
 #include <config.h>
+#include "nautilus-search-engine-tracker.h"
+
+#include "nautilus-global-preferences.h"
 #include "nautilus-search-hit.h"
 #include "nautilus-search-provider.h"
-#include "nautilus-search-engine-tracker.h"
+
 #include <string.h>
 #include <gio/gio.h>
-
 #include <libtracker-sparql/tracker-sparql.h>
 
 struct NautilusSearchEngineTrackerDetails {
@@ -37,6 +38,8 @@ struct NautilusSearchEngineTrackerDetails {
 	gboolean       query_pending;
 	GQueue        *hits_pending;
 
+	gboolean       recursive;
+
 	GCancellable  *cancellable;
 };
 
@@ -235,6 +238,7 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
 	GString *sparql;
 	GList *mimetypes, *l;
 	gint mime_count;
+	gboolean recursive;
 
 	tracker = NAUTILUS_SEARCH_ENGINE_TRACKER (provider);
 
@@ -250,6 +254,9 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
 		return;
 	}
 
+	recursive = g_settings_get_boolean (nautilus_preferences, "enable-recursive-search");
+	tracker->details->recursive = recursive;
+
 	query_text = nautilus_query_get_text (tracker->details->query);
 	downcase = g_utf8_strdown (query_text, -1);
 	search_text = tracker_sparql_escape_string (downcase);
@@ -270,11 +277,15 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
 		g_string_append (sparql, "nie:mimeType ?mime ;");
 	}
 
-	g_string_append_printf (sparql,
-				" fts:match '\"%s*\"' . FILTER ("
-				" tracker:uri-is-descendant('%s', nie:url(?urn)) &&"
-				" fn:contains(fn:lower-case(nfo:fileName(?urn)), '%s')",
-				search_text, location_uri, search_text);
+	g_string_append_printf (sparql, " fts:match '\"%s*\"' . FILTER ( ", search_text);
+
+	if (!tracker->details->recursive) {
+		g_string_append_printf (sparql, "tracker:uri-is-parent('%s', nie:url(?urn)) && ", location_uri);
+	} else {
+		g_string_append_printf (sparql, "tracker:uri-is-descendant('%s', nie:url(?urn)) && ", location_uri);
+	}
+
+	g_string_append_printf (sparql, "fn:contains(fn:lower-case(nfo:fileName(?urn)), '%s')", search_text);
 
 	if (mime_count > 0) {
 		g_string_append (sparql, " && (");
