@@ -48,8 +48,7 @@ static NautilusIconInfo *
 nautilus_canvas_view_container_get_icon_images (NautilusCanvasContainer *container,
 					      NautilusCanvasIconData      *data,
 					      int                    size,
-					      gboolean               for_drag_accept,
-					      gboolean              *has_window_open)
+					      gboolean               for_drag_accept)
 {
 	NautilusCanvasView *canvas_view;
 	NautilusFile *file;
@@ -63,8 +62,6 @@ nautilus_canvas_view_container_get_icon_images (NautilusCanvasContainer *contain
 	canvas_view = get_canvas_view (container);
 	g_return_val_if_fail (canvas_view != NULL, NULL);
 	
-	*has_window_open = nautilus_file_has_open_window (file);
-
 	flags = NAUTILUS_FILE_ICON_FLAGS_USE_EMBLEMS |
 		NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS;
 
@@ -408,24 +405,6 @@ nautilus_canvas_view_container_compare_icons_by_name (NautilusCanvasContainer *c
 		 FALSE, FALSE);
 }
 
-static void
-nautilus_canvas_view_container_freeze_updates (NautilusCanvasContainer *container)
-{
-	NautilusCanvasView *canvas_view;
-	canvas_view = get_canvas_view (container);
-	g_return_if_fail (canvas_view != NULL);
-	nautilus_view_freeze_updates (NAUTILUS_VIEW (canvas_view));
-}
-
-static void
-nautilus_canvas_view_container_unfreeze_updates (NautilusCanvasContainer *container)
-{
-	NautilusCanvasView *canvas_view;
-	canvas_view = get_canvas_view (container);
-	g_return_if_fail (canvas_view != NULL);
-	nautilus_view_unfreeze_updates (NAUTILUS_VIEW (canvas_view));
-}
-
 static void
 nautilus_canvas_view_container_class_init (NautilusCanvasViewContainerClass *klass)
 {
@@ -442,8 +421,6 @@ nautilus_canvas_view_container_class_init (NautilusCanvasViewContainerClass *kla
 
 	ic_class->compare_icons = nautilus_canvas_view_container_compare_icons;
 	ic_class->compare_icons_by_name = nautilus_canvas_view_container_compare_icons_by_name;
-	ic_class->freeze_updates = nautilus_canvas_view_container_freeze_updates;
-	ic_class->unfreeze_updates = nautilus_canvas_view_container_unfreeze_updates;
 }
 
 static void
