@@ -107,12 +107,6 @@ struct NautilusCanvasViewDetails
 	gboolean supports_keep_aligned;
 };
 
-static gboolean
-file_is_not_in_recent (NautilusFile *file)
-{
-        return !nautilus_file_is_in_recent (file);
-}
-
 /* Note that the first item in this list is the default sort,
  * and that the items show up in the menu in the order they
  * appear in this list.
@@ -136,14 +130,12 @@ static const SortCriterion sort_criteria[] = {
 	{
 		NAUTILUS_FILE_SORT_BY_MTIME,
 		"modification date",
-		"modification-date",
-                file_is_not_in_recent
+		"modification-date"
 	},
 	{
 		NAUTILUS_FILE_SORT_BY_ATIME,
 		"access date",
-		"access-date",
-                nautilus_file_is_in_recent
+		"access-date"
 	},
 	{
 		NAUTILUS_FILE_SORT_BY_TRASHED_TIME,
@@ -976,6 +968,9 @@ action_zoom_to_level (GSimpleAction *action,
 	nautilus_canvas_view_zoom_to_level (view, zoom_level);
 
 	g_simple_action_set_state (G_SIMPLE_ACTION (action), state);
+	g_settings_set_enum (nautilus_icon_view_preferences,
+                             NAUTILUS_PREFERENCES_ICON_VIEW_DEFAULT_ZOOM_LEVEL,
+                             zoom_level);
 }
 
 static void
@@ -1017,19 +1012,6 @@ nautilus_canvas_view_can_rename_file (NautilusView *view, NautilusFile *file)
 	return NAUTILUS_VIEW_CLASS(nautilus_canvas_view_parent_class)->can_rename_file (view, file);
 }
 
-static void
-nautilus_canvas_view_start_renaming_file (NautilusView *view,
-				  NautilusFile *file,
-				  gboolean select_all)
-{
-	/* call parent class to make sure the right canvas is selected */
-	NAUTILUS_VIEW_CLASS(nautilus_canvas_view_parent_class)->start_renaming_file (view, file, select_all);
-	
-	/* start renaming */
-	nautilus_canvas_container_start_renaming_selected_item
-		(get_canvas_container (NAUTILUS_CANVAS_VIEW (view)), select_all);
-}
-
 const GActionEntry canvas_view_entries[] = {
 	{ "keep-aligned", NULL, NULL, "true", action_keep_aligned },
 	{ "reversed-order", NULL, NULL, "false", action_reversed_order },
@@ -1079,13 +1061,35 @@ nautilus_canvas_view_update_actions_state (NautilusView *view)
 
 	view_action_group = nautilus_view_get_action_group (view);
 	if (nautilus_canvas_view_supports_auto_layout (canvas_view)) {
-		g_action_group_change_action_state (view_action_group,
-						    "reversed-order",
-						    g_variant_new_boolean (NAUTILUS_CANVAS_VIEW (view)->details->sort_reversed));
+		GVariant *sort_state;
+		GVariant *reversed_state;
 
-		g_action_group_change_action_state (view_action_group,
-						    "sort",
-						    g_variant_new_string (NAUTILUS_CANVAS_VIEW (view)->details->sort->action_target_name));
+		/* When we change the sort action state, even using the same value, it triggers
+		 * the sort action changed handler, which reveals the selection, since we expect
+		 * the selection to be visible when the user changes the sort order. But we may
+		 * need to update the actions state for others reason than an actual sort change,
+		 * so we need to prevent to trigger the sort action changed handler for those cases.
+		 * To achieve this, check if the action state value actually changed before setting
+		 * it. The same happens to the reversed-order state.
+		 */
+		sort_state = g_action_group_get_action_state (view_action_group, "sort");
+		reversed_state = g_action_group_get_action_state (view_action_group, "reversed-order");
+
+		if (NAUTILUS_CANVAS_VIEW (view)->details->sort_reversed != g_variant_get_boolean (reversed_state)) {
+			g_action_group_change_action_state (view_action_group,
+							    "reversed-order",
+							    g_variant_new_boolean (NAUTILUS_CANVAS_VIEW (view)->details->sort_reversed));
+		}
+
+		if (g_strcmp0 (g_variant_get_string (sort_state, NULL),
+                               NAUTILUS_CANVAS_VIEW (view)->details->sort->action_target_name) != 0) {
+			g_action_group_change_action_state (view_action_group,
+                                                            "sort",
+                                                             g_variant_new_string (NAUTILUS_CANVAS_VIEW (view)->details->sort->action_target_name));
+		}
+
+		g_variant_unref (reversed_state);
+		g_variant_unref (sort_state);
 	}
 
 	action = g_action_map_lookup_action (G_ACTION_MAP (view_action_group), "keep-aligned");
@@ -1381,27 +1385,6 @@ icon_position_changed_callback (NautilusCanvasContainer *container,
 		 "1.0", scale_string);
 }
 
-/* Attempt to change the filename to the new text.  Notify user if operation fails. */
-static void
-icon_rename_ended_cb (NautilusCanvasContainer *container,
-		      NautilusFile *file,				    
-		      const char *new_name,
-		      NautilusCanvasView *canvas_view)
-{
-	g_assert (NAUTILUS_IS_FILE (file));
-
-	nautilus_view_set_is_renaming (NAUTILUS_VIEW (canvas_view), FALSE);
-
-	/* Don't allow a rename with an empty string. Revert to original 
-	 * without notifying the user.
-	 */
-	if ((new_name == NULL) || (new_name[0] == '\0')) {
-		return;
-	}
-
-	nautilus_rename_file (file, new_name, NULL, NULL);
-}
-
 static char *
 get_icon_uri_callback (NautilusCanvasContainer *container,
 		       NautilusFile *file,
@@ -1672,8 +1655,6 @@ create_canvas_container (NautilusCanvasView *canvas_view)
 				 G_CALLBACK (get_stored_icon_position_callback), canvas_view, 0);
 	g_signal_connect_object (canvas_container, "layout-changed",
 				 G_CALLBACK (layout_changed_callback), canvas_view, 0);
-	g_signal_connect_object (canvas_container, "icon-rename-ended",
-				 G_CALLBACK (icon_rename_ended_cb), canvas_view, 0);
 	g_signal_connect_object (canvas_container, "icon-stretch-started",
 				 G_CALLBACK (nautilus_view_update_context_menus), canvas_view,
 				 G_CONNECT_SWAPPED);
@@ -1880,7 +1861,6 @@ nautilus_canvas_view_class_init (NautilusCanvasViewClass *klass)
         nautilus_view_class->click_policy_changed = nautilus_canvas_view_click_policy_changed;
 	nautilus_view_class->update_actions_state = nautilus_canvas_view_update_actions_state;
         nautilus_view_class->sort_directories_first_changed = nautilus_canvas_view_sort_directories_first_changed;
-        nautilus_view_class->start_renaming_file = nautilus_canvas_view_start_renaming_file;
 	nautilus_view_class->using_manual_layout = nautilus_canvas_view_using_manual_layout;
 	nautilus_view_class->widget_to_file_operation_position = nautilus_canvas_view_widget_to_file_operation_position;
 	nautilus_view_class->get_view_id = nautilus_canvas_view_get_id;
