@@ -17,8 +17,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Authors: John Sullivan <sullivan@eazel.com>
             Anders Carlsson <andersca@gnu.org>
@@ -54,6 +53,5 @@ typedef struct {
 
 GType nautilus_list_view_get_type (void);
 NautilusView * nautilus_list_view_new (NautilusWindowSlot *slot);
-GtkTreeView* nautilus_list_view_get_tree_view (NautilusListView *list_view);
 
 #endif /* NAUTILUS_LIST_VIEW_H */
