@@ -228,56 +228,6 @@ application_launch_parameters_free (ApplicationLaunchParameters *parameters)
 	g_list_free_full (parameters->uris, g_free);
 
 	g_free (parameters);
-}			      
-
-static GList*
-filter_nautilus_handler (GList *apps)
-{
-	GList *l, *next;
-	GAppInfo *application;
-	const char *id;
-
-	l = apps;
-	while (l != NULL) {
-		application = (GAppInfo *) l->data;
-		next = l->next;
-
-		id = g_app_info_get_id (application);
-		if (id != NULL &&
-		    strcmp (id,
-			    "nautilus.desktop") == 0) {
-			g_object_unref (application);
-			apps = g_list_delete_link (apps, l); 
-		}
-
-		l = next;
-	}
-
-	return apps;
-}
-
-static GList*
-filter_non_uri_apps (GList *apps,
-		     gboolean accept_files)
-{
-	GList *l, *next;
-	GAppInfo *app;
-
-	for (l = apps; l != NULL; l = next) {
-		gboolean support;
-
-		app = l->data;
-		next = l->next;
-		support = g_app_info_supports_uris (app);
-		if (accept_files) {
-			support |= g_app_info_supports_files (app);
-		}
-		if (!support) {
-			apps = g_list_delete_link (apps, l);
-			g_object_unref (app);
-		}
-	}
-	return apps;
 }
 
 static gboolean
@@ -385,77 +335,6 @@ file_compare_by_parent_uri (NautilusFile *file_a,
 	return ret;
 }
 
-static int
-application_compare_by_name (const GAppInfo *app_a,
-			     const GAppInfo *app_b)
-{
-	return g_utf8_collate (g_app_info_get_name ((GAppInfo *)app_a),
-			       g_app_info_get_name ((GAppInfo *)app_b));
-}
-
-static int
-application_compare_by_id (const GAppInfo *app_a,
-			   const GAppInfo *app_b)
-{
-	const char *id_a, *id_b;
-
-	id_a = g_app_info_get_id ((GAppInfo *)app_a);
-	id_b = g_app_info_get_id ((GAppInfo *)app_b);
-
-	if (id_a == NULL && id_b == NULL) {
-		if (g_app_info_equal ((GAppInfo *)app_a, (GAppInfo *)app_b)) {
-			return 0;
-		}
-		if ((gsize)app_a < (gsize) app_b) {
-			return -1;
-		}
-		return 1;
-	}
-
-	if (id_a == NULL) {
-		return -1;
-	}
-	
-	if (id_b == NULL) {
-		return 1;
-	}
-	
-	
-	return strcmp (id_a, id_b);
-}
-
-GList *
-nautilus_mime_get_applications_for_file (NautilusFile *file)
-{
-	char *mime_type;
-	char *uri_scheme;
-	GList *result;
-	GAppInfo *uri_handler;
-
-	if (!nautilus_mime_actions_check_if_required_attributes_ready (file)) {
-		return NULL;
-	}
-	mime_type = nautilus_file_get_mime_type (file);
-	result = g_app_info_get_all_for_type (mime_type);
-
-	uri_scheme = nautilus_file_get_uri_scheme (file);
-	if (uri_scheme != NULL) {
-		uri_handler = g_app_info_get_default_for_uri_scheme (uri_scheme);
-		if (uri_handler) {
-			result = g_list_prepend (result, uri_handler);
-		}
-		g_free (uri_scheme);
-	}
-
-	/* Filter out non-uri supporting apps */
-	result = filter_non_uri_apps (result, file_has_local_path (file));
-
-	result = g_list_sort (result, (GCompareFunc) application_compare_by_name);
-	g_free (mime_type);
-
-	return filter_nautilus_handler (result);
-}
-
 GAppInfo *
 nautilus_mime_get_default_application_for_files (GList *files)
 {
@@ -501,93 +380,6 @@ nautilus_mime_get_default_application_for_files (GList *files)
 	return app;
 }
 
-/* returns an intersection of two mime application lists,
- * and returns a new list, freeing a, b and all applications
- * that are not in the intersection set.
- * The lists are assumed to be pre-sorted by their IDs */
-static GList *
-intersect_application_lists (GList *a,
-			     GList *b)
-{
-	GList *l, *m;
-	GList *ret;
-	GAppInfo *a_app, *b_app;
-	int cmp;
-
-	ret = NULL;
-
-	l = a;
-	m = b;
-
-	while (l != NULL && m != NULL) {
-		a_app = (GAppInfo *) l->data;
-		b_app = (GAppInfo *) m->data;
-
-		cmp = application_compare_by_id (a_app, b_app);
-		if (cmp > 0) {
-			g_object_unref (b_app);
-			m = m->next;
-		} else if (cmp < 0) {
-			g_object_unref (a_app);
-			l = l->next;
-		} else {
-			g_object_unref (b_app);
-			ret = g_list_prepend (ret, a_app);
-			l = l->next;
-			m = m->next;
-		}
-	}
-
-	g_list_foreach (l, (GFunc) g_object_unref, NULL);
-	g_list_foreach (m, (GFunc) g_object_unref, NULL);
-
-	g_list_free (a);
-	g_list_free (b);
-
-	return g_list_reverse (ret);
-}
-
-GList *
-nautilus_mime_get_applications_for_files (GList *files)
-{
-	GList *l, *sorted_files;
-	NautilusFile *file;
-	GList *one_ret, *ret;
-
-	g_assert (files != NULL);
-
-	sorted_files = g_list_sort (g_list_copy (files), (GCompareFunc) file_compare_by_mime_type);
-
-	ret = NULL;
-	for (l = sorted_files; l != NULL; l = l->next) {
-		file = l->data;
-
-		if (l->prev &&
-		    file_compare_by_mime_type (file, l->prev->data) == 0 &&
-		    file_compare_by_parent_uri (file, l->prev->data) == 0) {
-			continue;
-		}
-
-		one_ret = nautilus_mime_get_applications_for_file (file);
-		one_ret = g_list_sort (one_ret, (GCompareFunc) application_compare_by_id);
-		if (ret != NULL) {
-			ret = intersect_application_lists (ret, one_ret);
-		} else {
-			ret = one_ret;
-		}
-
-		if (ret == NULL) {
-			break;
-		}
-	}
-
-	g_list_free (sorted_files);
-
-	ret = g_list_sort (ret, (GCompareFunc) application_compare_by_name);
-	
-	return ret;
-}
-
 static void
 trash_or_delete_files (GtkWindow *parent_window,
 		       const GList *files,
