@@ -248,12 +248,6 @@ struct NautilusViewClass {
 
 	gboolean (* can_rename_file)            (NautilusView *view,
 						 NautilusFile *file);
-	/* select_all specifies whether the whole filename should be selected
-	 * or only its basename (i.e. everything except the extension)
-	 * */
-	void	 (* start_renaming_file)        (NautilusView *view,
-					  	 NautilusFile *file,
-						 gboolean select_all);
 
 	/* convert *point from widget's coordinate system to a coordinate
 	 * system used for specifying file operation positions, which is view-specific.
@@ -297,7 +291,6 @@ char *              nautilus_view_get_uri                          (NautilusView
 void                nautilus_view_display_selection_info           (NautilusView  *view);
 
 GdkAtom	            nautilus_view_get_copied_files_atom            (NautilusView  *view);
-gboolean            nautilus_view_get_active                       (NautilusView  *view);
 
 /* Wrappers for signal emitters. These are normally called 
  * only by NautilusView itself. They have corresponding signals
@@ -333,11 +326,6 @@ void                nautilus_view_set_show_foreign                 (NautilusView
 gboolean            nautilus_view_handle_scroll_event              (NautilusView  *view,
 								    GdkEventScroll   *event);
 
-void                nautilus_view_freeze_updates                   (NautilusView  *view);
-void                nautilus_view_unfreeze_updates                 (NautilusView  *view);
-gboolean            nautilus_view_get_is_renaming                  (NautilusView  *view);
-void                nautilus_view_set_is_renaming                  (NautilusView  *view,
-								    gboolean       renaming);
 void                nautilus_view_add_subdirectory                (NautilusView  *view,
 								   NautilusDirectory*directory);
 void                nautilus_view_remove_subdirectory             (NautilusView  *view,
@@ -402,7 +390,6 @@ void              nautilus_view_update_context_menus       (NautilusView      *v
 void              nautilus_view_update_toolbar_menus       (NautilusView      *view);
 void              nautilus_view_update_actions_state       (NautilusView      *view);
 
-gboolean          nautilus_view_get_show_hidden_files      (NautilusView      *view);
 void		  nautilus_view_action_show_hidden_files   (NautilusView      *view,
 							    gboolean           show_hidden);
 
