@@ -83,10 +83,6 @@ static void mouse_forward_button_changed	     (gpointer                  callbac
 static void use_extra_mouse_buttons_changed          (gpointer                  callback_data);
 static void nautilus_window_initialize_actions 	     (NautilusWindow *window);
 static GtkWidget * nautilus_window_ensure_location_entry (NautilusWindow *window);
-void               nautilus_window_set_active_slot                     (NautilusWindow    *window,
-                                                                        NautilusWindowSlot *slot);
-void               nautilus_window_prompt_for_location                 (NautilusWindow *window,
-                                                                        GFile          *location);
 
 /* Sanity check: highest mouse button value I could find was 14. 5 is our 
  * lower threshold (well-documented to be the one of the button events for the 
@@ -379,10 +375,14 @@ action_prompt_for_location_root (GSimpleAction *action,
 				 GVariant      *state,
 				 gpointer       user_data)
 {
+	NautilusWindow *window = user_data;
 	GFile *location;
+	GtkWidget *entry;
 
 	location = g_file_new_for_path ("/");
-	nautilus_window_prompt_for_location (NAUTILUS_WINDOW (user_data), location);
+	entry = nautilus_window_ensure_location_entry (window);
+	nautilus_location_entry_set_location (NAUTILUS_LOCATION_ENTRY (entry), location);
+
 	g_object_unref (location);
 }
 
@@ -577,8 +577,8 @@ nautilus_window_initialize_actions (NautilusWindow *window)
 
 	/* Alt+N for the first 9 tabs */
 	for (i = 0; i < 9; ++i) {
-		g_snprintf(detailed_action, sizeof (detailed_action), "win.go-to-tab(%i)", i);
-		g_snprintf(accel, sizeof (accel), "<alt>%i", i + 1);
+		g_snprintf (detailed_action, sizeof (detailed_action), "win.go-to-tab(%i)", i);
+		g_snprintf (accel, sizeof (accel), "<alt>%i", i + 1);
 		nautilus_application_add_accelerator (app, detailed_action, accel);
 	}
 
@@ -603,18 +603,6 @@ nautilus_window_go_to (NautilusWindow *window, GFile *location)
 					    location, 0);
 }
 
-void
-nautilus_window_go_to_full (NautilusWindow *window,
-			    GFile          *location,
-			    NautilusWindowGoToCallback callback,
-			    gpointer        user_data)
-{
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-
-	nautilus_window_slot_open_location_full (nautilus_window_get_active_slot (window),
-						 location, 0, NULL, callback, user_data);
-}
-
 static int
 bookmark_list_get_uri_index (GList *list, GFile *location)
 {
@@ -886,19 +874,6 @@ nautilus_window_get_notebook (NautilusWindow *window)
 	return window->priv->notebook;
 }
 
-void
-nautilus_window_prompt_for_location (NautilusWindow *window,
-				     GFile          *location)
-{
-	GtkWidget *entry;
-
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-	g_return_if_fail (G_IS_FILE (location));
-
-	entry = nautilus_window_ensure_location_entry (window);
-	nautilus_location_entry_set_location (NAUTILUS_LOCATION_ENTRY (entry), location);
-}
-
 /* Code should never force the window taller than this size.
  * (The user can still stretch the window taller if desired).
  */
@@ -996,6 +971,34 @@ setup_side_pane_width (NautilusWindow *window)
 				window->priv->side_pane_width);
 }
 
+static void
+nautilus_window_location_opened (NautilusWindow *window,
+                                 GFile          *location,
+                                 GError         *error,
+                                 gpointer        user_data)
+{
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
+	if (error) {
+		NautilusFile *old_file;
+		GFile *old_location;
+
+		old_file = nautilus_window_slot_get_file (window->priv->active_slot);
+		old_location = nautilus_file_get_location (old_file);
+
+		gtk_places_sidebar_set_location (GTK_PLACES_SIDEBAR (window->priv->places_sidebar), old_location);
+
+		g_warning ("error opening location: %s", error->message);
+
+		nautilus_window_slot_display_view_selection_failure (window,
+                                                                     old_file,
+                                                                     location,
+                                                                     error);
+
+		g_object_unref (old_location);
+	}
+}
+
 /* Callback used when the places sidebar changes location; we need to change the displayed folder */
 static void
 places_sidebar_open_location_cb (GtkPlacesSidebar	*sidebar,
@@ -1021,7 +1024,12 @@ places_sidebar_open_location_cb (GtkPlacesSidebar	*sidebar,
 		break;
 	}
 
-	nautilus_window_slot_open_location (window->priv->active_slot, location, flags);
+	nautilus_window_slot_open_location_full (window->priv->active_slot,
+                                                 location,
+                                                 flags,
+                                                 NULL,
+                                                 (NautilusWindowGoToCallback) nautilus_window_location_opened,
+                                                 NULL);
 }
 
 /* Callback used when the places sidebar needs us to present an error message */
@@ -1362,20 +1370,6 @@ nautilus_window_show_sidebar (NautilusWindow *window)
 	setup_side_pane_width (window);
 }
 
-gboolean
-nautilus_window_disable_chrome_mapping (GValue *value,
-					GVariant *variant,
-					gpointer user_data)
-{
-	NautilusWindow *window = user_data;
-
-	g_value_set_boolean (value,
-			     g_variant_get_boolean (variant) &&
-			     !window->priv->disable_chrome);
-
-	return TRUE;
-}
-
 static inline NautilusWindowSlot *
 get_first_inactive_slot (NautilusWindow *window)
 {
@@ -2271,17 +2265,6 @@ nautilus_window_key_press_event (GtkWidget *widget,
 	active_slot = nautilus_window_get_active_slot (window);
 	view =  nautilus_window_slot_get_view (active_slot);
 
-	if (view != NULL && nautilus_view_get_is_renaming (view)) {
-		/* if we're renaming, just forward the event to the
-		 * focused widget and return. We don't want to process the window
-		 * accelerator bindings, as they might conflict with the 
-		 * editable widget bindings.
-		 */
-		if (gtk_window_propagate_key_event (GTK_WINDOW (window), event)) {
-			return TRUE;
-		}
-	}
-
 	focus_widget = gtk_window_get_focus (GTK_WINDOW (window));
 	if (view != NULL && focus_widget != NULL &&
 	    GTK_IS_EDITABLE (focus_widget)) {
