@@ -108,15 +108,13 @@ void             nautilus_window_close                (NautilusWindow    *window
 
 void             nautilus_window_go_to                (NautilusWindow    *window,
                                                        GFile             *location);
-void             nautilus_window_go_to_full           (NautilusWindow    *window,
-                                                       GFile             *location,
-                                                       NautilusWindowGoToCallback callback,
-                                                       gpointer           user_data);
 void             nautilus_window_new_tab              (NautilusWindow    *window);
 
 void                 nautilus_window_view_visible          (NautilusWindow *window,
                                                             NautilusView *view);
 NautilusWindowSlot * nautilus_window_get_active_slot       (NautilusWindow *window);
+void                 nautilus_window_set_active_slot       (NautilusWindow    *window,
+                                                            NautilusWindowSlot *slot);
 GList *              nautilus_window_get_slots             (NautilusWindow *window);
 NautilusWindowSlot * nautilus_window_open_slot             (NautilusWindow *window,
                                                             NautilusWindowOpenSlotFlags flags);
@@ -136,11 +134,6 @@ void nautilus_window_reset_menus (NautilusWindow *window);
 
 GtkWidget *         nautilus_window_get_notebook (NautilusWindow *window);
 
-
-gboolean nautilus_window_disable_chrome_mapping (GValue *value,
-                                                 GVariant *variant,
-                                                 gpointer user_data);
-
 NautilusWindowOpenFlags nautilus_event_get_window_open_flags   (void);
 void     nautilus_window_show_about_dialog    (NautilusWindow *window);
 
